#!/bin/bash
set -u
set -e

if csrutil status | grep enable > /dev/null; then
  if kextstat | grep DisplayLink > /dev/null; then
    echo "Installer has detected potential system cache integrity issue."
    echo "Please go to macOS Recovery mode, open terminal there and disable System integrity protection using command: csrutil disable"
    exit -1
  fi
  echo "System cache integrity is correct. Please install DisplayLink driver ..."
  exit 0
fi

if csrutil status | grep disable > /dev/null; then
  # the following commands are executed with disabled System Integrity Protection to trigger pre-linked kernel update
  echo "Fixing system cache integrity..."
  sudo rm -rf /Library/Extensions/DisplayLinkDriver.kext
  sudo touch /Library/Extensions
  sudo csrutil clear
  if test -d /Applications/DisplayLink/DisplayLink\ Software\ Uninstaller.app; then
    echo "Uninstalling DisplayLink software"
    open /Applications/DisplayLink/DisplayLink\ Software\ Uninstaller.app
  fi
  echo "System cache integrity fixed. Enabling System integrity protection and rebooting"
  sudo reboot
fi
